Module kill_tree::blocking

source ·

Functions

  • Kills the target process and all of its children recursively.
  • Kills the target process and all of its children recursively using the given Config.